@@ -16,7 +16,7 @@ from meilisearch.config import Config
 from meilisearch.errors import MeilisearchError
 from meilisearch.index import Index
 from meilisearch.models.key import Key, KeysResults
-from meilisearch.models.task import Task, TaskInfo, TaskResults
+from meilisearch.models.task import Batch, BatchResults, Task, TaskInfo, TaskResults
 from meilisearch.task import TaskHandler
 
 
@@ -34,6 +34,7 @@ class Client:
         api_key: Optional[str] = None,
         timeout: Optional[int] = None,
         client_agents: Optional[Tuple[str, ...]] = None,
+        custom_headers: Optional[Mapping[str, str]] = None,
     ) -> None:
         """
         Parameters
@@ -48,10 +49,13 @@ class Client:
         client_agents (optional):
             Used to send additional client agent information for clients extending the functionality
             of this client.
+        custom_headers (optional):
+            Custom headers to add when sending data to Meilisearch.
         """
+
         self.config = Config(url, api_key, timeout=timeout, client_agents=client_agents)
 
-        self.http = HttpRequests(self.config)
+        self.http = HttpRequests(self.config, custom_headers)
 
         self.task_handler = TaskHandler(self.config)
 
@@ -248,6 +252,33 @@ class Client:
             body={"queries": queries, "federation": federation},
         )
 
+    def update_documents_by_function(
+        self, index_uid: str, queries: Dict[str, List[Dict[str, Any]]]
+    ) -> Dict[str, Any]:
+        """Update Documents by function
+        Parameters
+        ----------
+        index_uid:
+            The index_uid where you want to update documents of.
+        queries:
+            List of dictionaries containing functions with or without filters that you want to use to update documents.
+
+        Returns
+        -------
+        task_info:
+            TaskInfo instance containing information about a task to track the progress of an asynchronous process.
+            https://www.meilisearch.com/docs/reference/api/tasks#get-one-task
+
+        Raises
+        ------
+        MeilisearchApiError
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
+        """
+        return self.http.post(
+            path=f"{self.config.paths.index}/{index_uid}/{self.config.paths.document}/{self.config.paths.edit}",
+            body=dict(queries),
+        )
+
     def get_all_stats(self) -> Dict[str, Any]:
         """Get all stats of Meilisearch
 
@@ -611,6 +642,46 @@ class Client:
         """
         return self.task_handler.wait_for_task(uid, timeout_in_ms, interval_in_ms)
 
+    def get_batches(self, parameters: Optional[MutableMapping[str, Any]] = None) -> BatchResults:
+        """Get all batches.
+
+        Parameters
+        ----------
+        parameters (optional):
+            parameters accepted by the get batches route: https://www.meilisearch.com/docs/reference/api/batches#get-batches.
+
+        Returns
+        -------
+        batch:
+            BatchResult instance containing limit, from, next and results containing a list of all batches.
+
+        Raises
+        ------
+        MeilisearchApiError
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
+        """
+        return self.task_handler.get_batches(parameters=parameters)
+
+    def get_batch(self, uid: int) -> Batch:
+        """Get one tasks batch.
+
+        Parameters
+        ----------
+        uid:
+            Identifier of the batch.
+
+        Returns
+        -------
+        batch:
+            Batch instance containing information about the progress of the asynchronous batch.
+
+        Raises
+        ------
+        MeilisearchApiError
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
+        """
+        return self.task_handler.get_batch(uid)
+
     def generate_tenant_token(
         self,
         api_key_uid: str,
