@@ -30,9 +30,11 @@ from meilisearch.models.index import (
     HuggingFaceEmbedder,
     IndexStats,
     LocalizedAttributes,
+    OllamaEmbedder,
     OpenAiEmbedder,
     Pagination,
     ProximityPrecision,
+    RestEmbedder,
     TypoTolerance,
     UserProvidedEmbedder,
 )
@@ -953,12 +955,23 @@ class Index:
         )
 
         if settings.get("embedders"):
-            embedders: dict[str, OpenAiEmbedder | HuggingFaceEmbedder | UserProvidedEmbedder] = {}
+            embedders: dict[
+                str,
+                OpenAiEmbedder
+                | HuggingFaceEmbedder
+                | OllamaEmbedder
+                | RestEmbedder
+                | UserProvidedEmbedder,
+            ] = {}
             for k, v in settings["embedders"].items():
                 if v.get("source") == "openAi":
                     embedders[k] = OpenAiEmbedder(**v)
+                elif v.get("source") == "ollama":
+                    embedders[k] = OllamaEmbedder(**v)
                 elif v.get("source") == "huggingFace":
                     embedders[k] = HuggingFaceEmbedder(**v)
+                elif v.get("source") == "rest":
+                    embedders[k] = RestEmbedder(**v)
                 else:
                     embedders[k] = UserProvidedEmbedder(**v)
 
@@ -1881,12 +1894,23 @@ class Index:
         if not response:
             return None
 
-        embedders: dict[str, OpenAiEmbedder | HuggingFaceEmbedder | UserProvidedEmbedder] = {}
+        embedders: dict[
+            str,
+            OpenAiEmbedder
+            | HuggingFaceEmbedder
+            | OllamaEmbedder
+            | RestEmbedder
+            | UserProvidedEmbedder,
+        ] = {}
         for k, v in response.items():
             if v.get("source") == "openAi":
                 embedders[k] = OpenAiEmbedder(**v)
+            elif v.get("source") == "ollama":
+                embedders[k] = OllamaEmbedder(**v)
             elif v.get("source") == "huggingFace":
                 embedders[k] = HuggingFaceEmbedder(**v)
+            elif v.get("source") == "rest":
+                embedders[k] = RestEmbedder(**v)
             else:
                 embedders[k] = UserProvidedEmbedder(**v)
 
